IF OBJECT_ID('[Servers_Extended]') IS NOT NULL DROP VIEW [Servers_Extended]
GO

CREATE VIEW [Servers_Extended]
AS
    SELECT S.[Server_Id],
	       S.[Raft_Id],
		   S.[ServerStatus_Code],
		   S.[Server_Name],
		   S.[RoutineExecutionType_Code],
		   S.[Agent_Configuration],
		   S.[Active_Indicator],
		   S.[CollectOperations_Csv],
		   S.[Agent_Version],

		   [ServerConfiguration_Status_Code] = CASE WHEN SC_DRIFT.[Priority_Index] < 2 THEN 'D' WHEN SC_DRIFT.[Priority_Index] >= 2 THEN 'C' ELSE 'U' END,
		   [AllDriftPendingRemediation_Indicator] = CASE WHEN SC_DRIFT.[Priority_Index] = 1 THEN 'Y' ELSE 'N' END,
           [FinalRemediation_Job_Start_Date] = J_FINAL.[Start_Date],
           S.[FinalRemediation_Job_Id],

           R.[Raft_Name],

           [Latest_CollectionRun_Start_Date] = E_LATEST.[Start_Date],
           S.[Latest_CollectionRun_Execution_Id],
           [Latest_CollectionRun_Execution_Status] = E_LATEST.[ExecutionStatus_Code],
           [Latest_CollectionRun_Execution_RunState] = E_LATEST.[ExecutionRunState_Code]

      FROM [Servers] S
	       LEFT JOIN [Executions] E_LATEST
		          ON E_LATEST.[Execution_Id] = S.[Latest_CollectionRun_Execution_Id]
		   LEFT JOIN [Jobs] J_FINAL
		          ON J_FINAL.[Job_Id] = S.[FinalRemediation_Job_Id]
           LEFT JOIN [Rafts] R
                  ON R.[Raft_Id] = S.[Raft_Id]
		   LEFT JOIN (SELECT [Server_Id],
                             [Priority_Index] = MIN([ServerConfiguration_Status_Priority])
                        FROM [ServerConfigurations]
                       GROUP BY [Server_Id]) SC_DRIFT
				  ON SC_DRIFT.[Server_Id] = S.[Server_Id]

GO
