EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ServerPackages_CreateOrUpdatePackage',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates a server package.'
GO

IF OBJECT_ID('[ServerPackages_CreateOrUpdatePackage]') IS NOT NULL DROP PROCEDURE [ServerPackages_CreateOrUpdatePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ServerPackages_CreateOrUpdatePackage]
(
	@Server_Id INT,
    @PackageType_Name NVARCHAR(50),
    @Package_Name NVARCHAR(255),
    @Package_Version VARCHAR(50),
    @CollectedOn_Execution_Id INT,
    @Url_Text NVARCHAR(255),
	@CollectedFor_ServerRole_Id INT,
	@PackageDetails_Xml XML = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF NOT EXISTS(
        SELECT *
          FROM [ServerPackages]
         WHERE [Server_Id] = @Server_Id
           AND [PackageType_Name] = @PackageType_Name
           AND [Package_Name] = @Package_Name
    )
    BEGIN

		INSERT INTO [ServerPackages] 
        (   
            [Server_Id],
            [PackageType_Name],
            [Package_Name],
            [Package_Version],
            [CollectedOn_Execution_Id],
            [Url_Text],
			[CollectedFor_ServerRole_Id],
			[PackageDetails_Xml]
        )
		VALUES 
        (
            @Server_Id,
            @PackageType_Name,
            @Package_Name,
            COALESCE(@Package_Version, ''),
            @CollectedOn_Execution_Id,
            @Url_Text,
			@CollectedFor_ServerRole_Id,
			@PackageDetails_Xml
        )

	END ELSE 
    BEGIN

		UPDATE [ServerPackages]
		   SET [CollectedOn_Execution_Id] = @CollectedOn_Execution_Id,
               [Url_Text] = @Url_Text,
			   [CollectedFor_ServerRole_Id] = @CollectedFor_ServerRole_Id,
			   [Package_Version] = COALESCE(@Package_Version, ''),
			   [PackageDetails_Xml] = @PackageDetails_Xml
		 WHERE [Server_Id] = @Server_Id 
           AND [Package_Name] = @Package_Name 
           AND [PackageType_Name] = @PackageType_Name

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [ServerPackages_CreateOrUpdatePackage] TO [OtterUser_Role]
